@@ -1,4 +1,4 @@
-__version__ = "0.0.21"
+__version__ = "0.0.29"
 import matplotlib as mpl, pkgutil, requests, time
 from fastai.vision.all import *
 from fastdownload import download_url
@@ -38,6 +38,7 @@ def setup_book():
     if IN_COLAB: return setup_colab()
 
 def gv(s): return graphviz.Source('digraph G{ rankdir="LR"' + s + '; }')
+def gv2(s): return graphviz.Source(f'''digraph {{\nnode [ fontsize=24];\nrankdir="LR"\n{s};}}''')
 
 def get_image_files_sorted(path, recurse=True, folders=None):
     return get_image_files(path, recurse, folders).sorted()
@@ -59,17 +60,19 @@ def search_images_ddg(term, max_images=200):
     requestUrl = url + 'i.js'
     params = dict(l='us-en', o='json', q=term, vqd=searchObj.group(1), f=',,,', p='1', v7exp='a')
     urls,data = set(),{'next':1}
+    headers = dict(referer='https://duckduckgo.com/')
     while len(urls)<max_images and 'next' in data:
         try:
-            data = urljson(requestUrl,data=params)
+            res = urlread(requestUrl, data=params, headers=headers)
+            data = json.loads(res) if res else {}
             urls.update(L(data['results']).itemgot('image'))
             requestUrl = url + data['next']
         except (URLError,HTTPError): pass
-        time.sleep(0.2)
-    return L(urls)
+        time.sleep(1)
+    return L(urls)[:max_images]
 
 def plot_function(f, tx=None, ty=None, title=None, min=-2, max=2, figsize=(6,4)):
-    x = torch.linspace(min,max)
+    x = torch.linspace(min,max, 100)
     fig,ax = plt.subplots(figsize=figsize)
     ax.plot(x,f(x))
     if tx is not None: ax.set_xlabel(tx)
